@@ -3,11 +3,8 @@ import string
 from dataclasses import dataclass, field, fields
 from typing import List, Optional
 
-from airflow.models import DagRun, TaskInstance
 from sqlalchemy import Column, MetaData
 
-from astro.constants import UNIQUE_TABLE_NAME_LENGTH
-
 MAX_TABLE_NAME_LENGTH = 62
 TEMP_PREFIX = "_tmp_"
 
@@ -23,7 +20,7 @@ class Metadata:
     schema: Optional[str] = None
     database: Optional[str] = None
 
-    def is_empty(self):
+    def is_empty(self) -> bool:
         """Check if all the fields are None."""
         values = [getattr(self, field.name) for field in fields(self)]
         return values.count(None) == len(values)
@@ -51,7 +48,7 @@ class Table:
     columns: List[Column] = field(default_factory=list)
     temp: bool = False
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         if not self._name:
             self.temp = True
 
@@ -108,29 +105,3 @@ class Table:
         if not isinstance(value, property):
             self._name = value
             self.temp = False
-
-
-# TODO: deprecate by the end of the refactoring
-def create_table_name(context) -> str:
-    ti: TaskInstance = context["ti"]
-    dag_run: DagRun = ti.get_dagrun()
-    table_name = f"{dag_run.dag_id}_{ti.task_id}_{dag_run.id}".replace(
-        "-", "_"
-    ).replace(".", "__")[:MAX_TABLE_NAME_LENGTH]
-    if not table_name.isidentifier():
-        table_name = f'"{table_name}"'
-    return table_name
-
-
-# TODO: deprecate by the end of the refactoring
-def create_unique_table_name(length: int = UNIQUE_TABLE_NAME_LENGTH) -> str:
-    """
-    Create a unique table name of the requested size, which is compatible with all supported databases.
-
-    :return: Unique table name
-    :rtype: str
-    """
-    unique_id = random.choice(string.ascii_lowercase) + "".join(
-        random.choice(string.ascii_lowercase + string.digits) for _ in range(length - 1)
-    )
-    return unique_id
